@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001-2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -18,7 +18,7 @@ big improvement of the 'BrowserRequest' to 'HTTPRequest' is that is can handle
 HTML form data and convert them into a Python-native format. Even file data is
 packaged into a nice, Python-friendly 'FileUpload' object.
 
-$Id: browser.py 103282 2009-08-27 14:49:25Z nadako $
+$Id: browser.py 105429 2009-11-02 07:47:51Z ctheune $
 """
 __docformat__ = 'restructuredtext'
 
@@ -285,7 +285,15 @@ class BrowserRequest(HTTPRequest):
         if 'QUERY_STRING' not in self._environ:
             self._environ['QUERY_STRING'] = ''
 
-        fs = ZopeFieldStorage(fp=fp, environ=self._environ,
+        # The Python 2.6 cgi module mixes the query string and POST values
+        # together.  We do not want this.
+        env = self._environ
+        if self.method == 'POST' and self._environ['QUERY_STRING']:
+            env = env.copy()
+            del env['QUERY_STRING']
+
+
+        fs = ZopeFieldStorage(fp=fp, environ=env,
                               keep_blank_values=1)
 
         fslist = getattr(fs, 'list', None)
